@@ -1,7 +1,7 @@
-/* 
+/*
  *   Gnome Nibbles: Gnome Worm Game
  *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
- * 
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -36,13 +36,14 @@ typedef struct {
 } GnibblesWarpManager;
 
 GnibblesWarpManager *gnibbles_warpmanager_new (void);
-
-void gnibbles_warpmanager_destroy (GnibblesWarpManager * warpmanager);
-
-void gnibbles_warpmanager_add_warp (GnibblesWarpManager * warpmanager,
-				    gint t_x, gint t_y, gint t_wx, gint t_wy);
-
-void gnibbles_warpmanager_worm_change_pos (GnibblesWarpManager * warpmanager,
-					   GnibblesWorm * worm);
+void gnibbles_warpmanager_destroy (GnibblesWarpManager *warpmanager);
+void gnibbles_warpmanager_add_warp (GnibblesWarpManager *warpmanager,
+				                            gint t_x, gint t_y, gint t_wx, gint t_wy);
+void gnibbles_warpmanager_worm_change_pos (GnibblesWarpManager *warpmanager,
+					                                 GnibblesWorm *worm);
+void gnibbles_warpmanager_worm_change_tail_pos (GnibblesWarpManager *warpmanager,
+                                                GnibblesWorm *worm);
+void gnibbles_warpmanager_rescale (GnibblesWarpManager *warpmanager,
+                                  gint tilesize);
 
 #endif
