@@ -504,6 +504,12 @@ Tetris::setBastardMode(GtkWidget *widget, void *d)
 {
 	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_BASTARD_MODE,
 				gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)));
+
+	/* Disable the preview option to indicate that it is
+		unavailable in bastard mode */
+	Tetris *t = (Tetris*) d;
+	gtk_widget_set_sensitive(t->do_preview_toggle,
+		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) ? FALSE : TRUE);
 }
 
 void
@@ -696,6 +702,13 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			  G_CALLBACK (setBastardMode), d);
 	gtk_box_pack_start (GTK_BOX (fvbox), t->bastard_mode_toggle, 0, 0, 0);
 
+	/* If bastard mode is active then disable the preview option
+		to indicate that it is unavailable in bastard mode */
+	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (t->bastard_mode_toggle)))
+	{
+		gtk_widget_set_sensitive(t->do_preview_toggle, FALSE);
+	}
+
 	/* rotate counter clock wise */
  	t->rotate_counter_clock_wise_toggle =
 		gtk_check_button_new_with_mnemonic (_("_Rotate blocks counterclockwise"));
@@ -771,7 +784,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	t->theme_preview->setTheme (t->themeno);
 	gtk_box_pack_start(GTK_BOX(fvbox), t->theme_preview->getWidget(), TRUE, TRUE, 0);
 
-	t->theme_preview->previewBlock(4, 0);
+	t->theme_preview->previewBlock(4, 0, TRUE);
 
 	gtk_widget_show_all (t->setupdialog);
 	gtk_action_set_sensitive(t->new_game_action, FALSE);
@@ -1188,7 +1201,7 @@ Tetris::generate()
 	if (field->generateFallingBlock())
 	{
 		field->putBlockInField(FALLING);
-		preview->previewBlock(blocknr_next, color_next);
+		preview->previewBlock(blocknr_next, color_next, FALSE);
 		onePause = true;
 	}
 	else
@@ -1212,7 +1225,7 @@ Tetris::endOfGame()
 	color_next = -1;
 	blocknr_next = -1;
 	rot_next = -1;
-	preview->previewBlock(-1, -1);
+	preview->previewBlock(-1, -1, FALSE);
 	field->hidePauseMessage();
 	field->showGameOverMessage();
 	games_sound_play ("gameover");
@@ -1258,7 +1271,7 @@ Tetris::gameNew(GtkAction *action, void *d)
 
 	t->field->generateFallingBlock();
 	t->field->putBlockInField(FALLING);
-	t->preview->previewBlock(blocknr_next, color_next);
+	t->preview->previewBlock(blocknr_next, color_next, FALSE);
 
 	gtk_action_set_sensitive(t->pause_action, TRUE);
 	gtk_action_set_sensitive(t->end_game_action, TRUE);
